/********************************************************************************************************\

	File Name:	CommonDestroyerBaseState.cpp
	Descript:	<DESCRIPTION>

\********************************************************************************************************/

#include "MissionText.h"
#include "CommonDefs.h"
#include "CommonDestroyerBaseState.h"
#include "CommonLightCruiser.h"
#include "ScriptInterface.h"
#include "WorldConditions.h"


/*

	HELPER NOTE:	There are so many things that can be done here depending upon which mission you are
					coding.  So rather than list out possible bodies for each of the events below, the
					signatures have been given to save time cutting and pasting.  However, if you do need
					examples of the bodies of these functions, please feel free to refer back to ISC_5Accuse,
					which is the latest mission and the mission that contains files that most closely reflect
					this file and others in this script.

*/
void tCommonDestroyerBaseState::mBeginState()
{
	mSetTimedInterval( kTimerTurnsSet, kInvincibility_TID, 0.5f );
}
void tCommonDestroyerBaseState::mEndState()
{}

void tCommonDestroyerBaseState::mOnDeath( tShipInfo* ship )
{
	if ( !ship )
		return;

	eTeamID		teamID = ship->mGetTeam();
	tTeamInfo*	team = fMissionInfo->mGetTeamHandle( teamID );

	Assert( team );
	if ( !team )
		return;

	if ( fChildActor->mGetTeam() == teamID )
	{
		if ( fChildActor->mGetCustomID() == ship->mGetCustomID() )
		{

			//
			//	The Destroyer is lost, so spawn a Light Cruiser.
			//
			gWC.mSetDestroyerDestroyed( teamID, true );
			/*
			*/

			// create the ship
			Ship s;
			int classic_style = 0;
			ShipList tmpsl = sl_array[(int32 )team->mGetTeam()][(int32 )team->mGetRace()][2];

			if (tmpsl.size() == 0) {
				tmpsl = sl_array_backup[(int32 )team->mGetTeam()][(int32 )team->mGetRace()][2];
				if (tmpsl.size() == 0) {
					tmpsl = sl_array[(int32 )team->mGetTeam()][(int32 )team->mGetRace()][1];
					if (tmpsl.size() == 0) {
						classic_style = 1;
					}
				}
			}

			if (!classic_style) {
				int result = tmpsl.SelectRandomShip(s);
				team->mCreateShip(	typeid( tCommonLightCruiser ),
						s.shipCode.c_str(),
						gWC.mGenerateRandomStartPosition(),
						kLightCruiser,
						kLightCruiser, 
						0, 0, -1, -1, NULL,
						static_cast< eShipOptions >( kDefaultShipOptions | kDeathUponDisengage ) );
			} else {
				team->mCreateShip(	typeid( tCommonLightCruiser ),
						kMaxBPV,
						kClassLightCruiser,
						100,
						gWC.mGenerateRandomStartPosition(),
						kLightCruiser,
						0, 0, -1, -1, NULL,
						static_cast< eShipOptions >( kDefaultShipOptions | kDeathUponDisengage ) );
			}

		}
	}
}
void tCommonDestroyerBaseState::mOnCapture( tShipInfo* ship )
{}
void tCommonDestroyerBaseState::mOnDisengaged( tShipInfo* ship )
{}
void tCommonDestroyerBaseState::mAtDistance( tShipInfo* ship )
{}
void tCommonDestroyerBaseState::mAtDestination( tShipInfo* ship )
{}
void tCommonDestroyerBaseState::mOnCommButtonPress( tShipInfo* ship, int32 buttonID, tShipInfo* targetShip )
{}
void tCommonDestroyerBaseState::mOnDamage( tShipInfo* damagedShip, tShipInfo* hostileShip, eDamageToShip damageType )
{}
void tCommonDestroyerBaseState::mOnDeepScan( tShipInfo* ship, iTruth deepScanOn )
{}
void tCommonDestroyerBaseState::mOnAlertStatusChange( tShipInfo* ship, eAlertLevels alertStatus )
{}
void tCommonDestroyerBaseState::mOnProbeLaunch( tShipInfo* ship )
{}
void tCommonDestroyerBaseState::mOnBeginOrbit( tShipInfo* ship )
{}
void tCommonDestroyerBaseState::mOnEndOrbit( tShipInfo* ship )
{}
void tCommonDestroyerBaseState::mOnBeginTractor( tShipInfo* tractorTarget, tShipInfo* tractoringShip )
{}
void tCommonDestroyerBaseState::mOnEndTractor( tShipInfo* tractorTarget, tShipInfo* tractoringShip )
{}
void tCommonDestroyerBaseState::mOnFlashingButtonPressed()
{}
void tCommonDestroyerBaseState::mOnTransportedItem( tShipInfo* shipTo, tShipInfo* shipFrom, eScriptTransportItems item )
{}
void tCommonDestroyerBaseState::mOnChangingShip( tShipInfo* ship )
{}
void tCommonDestroyerBaseState::mOnSpecialTransport( tShipInfo* ship )
{}

void tCommonDestroyerBaseState::mOnPlayerLeaving( int32 playerNumber, eTeamID TeamID )
{}
void tCommonDestroyerBaseState::mOnHostChanged()
{}
void tCommonDestroyerBaseState::mOnTimedInterval( int32 timerID )
{
	switch ( timerID )
	{
	case kInvincibility_TID:
		{
			fChildActor->mSetTargetable( kTrue );
		}
		break;
	}
}
void tCommonDestroyerBaseState::mOnStateChange( tActor* actor, tState* stateID, eStateEvent eventType )
{}
void tCommonDestroyerBaseState::mOnCommStateChange( tActor* actor, int32 state, int32 buttonID, eStateEvent eventType )
{}


