/********************************************************************************************************\

	File Name:	CommonFrigateBaseState.cpp
	Descript:	<DESCRIPTION>

\********************************************************************************************************/

#include "MissionText.h"
#include "CommonDefs.h"
#include "CommonFrigateBaseState.h"
#include "CommonDestroyer.h"
#include "ScriptInterface.h"
#include "WorldConditions.h"


/*

	HELPER NOTE:	There are so many things that can be done here depending upon which mission you are
					coding.  So rather than list out possible bodies for each of the events below, the
					signatures have been given to save time cutting and pasting.  However, if you do need
					examples of the bodies of these functions, please feel free to refer back to ISC_5Accuse,
					which is the latest mission and the mission that contains files that most closely reflect
					this file and others in this script.

*/
void tCommonFrigateBaseState::mBeginState()
{}

void tCommonFrigateBaseState::mEndState()
{}

void tCommonFrigateBaseState::mOnDeath( tShipInfo* ship )
{
	if ( !ship )
		return;

	eTeamID		teamID = ship->mGetTeam();
	tTeamInfo*	team = fMissionInfo->mGetTeamHandle( teamID );

	Assert( team );
	if ( !team )
		return;

	if ( fChildActor->mGetTeam() == teamID )
	{
		if ( fChildActor->mGetCustomID() == ship->mGetCustomID() )
		{

			//
			//	The Frigate is lost, so spawn a Destroyer.
			//
			gWC.mSetFrigateDestroyed( teamID, true );



			// create the ship
			Ship s;
			int classic_style = 0;
			ShipList tmpsl = sl_array[(int32 )team->mGetTeam()][(int32 )team->mGetRace()][1];

			if (tmpsl.size() == 0) {
				// if there are no ships in the DD class, select from backup DD list
				tmpsl = sl_array_backup[(int32 )team->mGetTeam()][(int32 )team->mGetRace()][1];
				if (tmpsl.size() == 0) {
					// if there are no ships in the DD class, select from FFs
					tmpsl = sl_array[(int32 )team->mGetTeam()][(int32 )team->mGetRace()][0];
					if (tmpsl.size() == 0) {
						// no use. Select the classic way.
						classic_style = 1;
					}
				}
			}

			if (!classic_style) {
				int result = tmpsl.SelectRandomShip(s);
				team->mCreateShip(	typeid( tCommonDestroyer ),
					s.shipCode.c_str(),
					gWC.mGenerateRandomStartPosition(),
					kDestroyer,
					kDestroyer, 
					0, 0, -1, -1, NULL,
					static_cast< eShipOptions >( kDefaultShipOptions | kDeathUponDisengage ) );
			} else {
				team->mCreateShip(	typeid( tCommonDestroyer ),
					kMaxBPV,
					kClassDestroyer,
					100,
					gWC.mGenerateRandomStartPosition(),
					kDestroyer,
					0, 0, -1, -1, NULL,
					static_cast< eShipOptions >( kDefaultShipOptions | kDeathUponDisengage ) );
			}
		}
	}
}
void tCommonFrigateBaseState::mOnCapture( tShipInfo* ship )
{}
void tCommonFrigateBaseState::mOnDisengaged( tShipInfo* ship )
{}
void tCommonFrigateBaseState::mAtDistance( tShipInfo* ship )
{}
void tCommonFrigateBaseState::mAtDestination( tShipInfo* ship )
{}
void tCommonFrigateBaseState::mOnCommButtonPress( tShipInfo* ship, int32 buttonID, tShipInfo* targetShip )
{}
void tCommonFrigateBaseState::mOnDamage( tShipInfo* damagedShip, tShipInfo* hostileShip, eDamageToShip damageType )
{}
void tCommonFrigateBaseState::mOnDeepScan( tShipInfo* ship, iTruth deepScanOn )
{}
void tCommonFrigateBaseState::mOnAlertStatusChange( tShipInfo* ship, eAlertLevels alertStatus )
{}
void tCommonFrigateBaseState::mOnProbeLaunch( tShipInfo* ship )
{}
void tCommonFrigateBaseState::mOnBeginOrbit( tShipInfo* ship )
{}
void tCommonFrigateBaseState::mOnEndOrbit( tShipInfo* ship )
{}
void tCommonFrigateBaseState::mOnBeginTractor( tShipInfo* tractorTarget, tShipInfo* tractoringShip )
{}
void tCommonFrigateBaseState::mOnEndTractor( tShipInfo* tractorTarget, tShipInfo* tractoringShip )
{}
void tCommonFrigateBaseState::mOnFlashingButtonPressed()
{}
void tCommonFrigateBaseState::mOnTransportedItem( tShipInfo* shipTo, tShipInfo* shipFrom, eScriptTransportItems item )
{}
void tCommonFrigateBaseState::mOnChangingShip( tShipInfo* ship )
{}
void tCommonFrigateBaseState::mOnSpecialTransport( tShipInfo* ship )
{}

void tCommonFrigateBaseState::mOnPlayerLeaving( int32 playerNumber, eTeamID TeamID )
{}
void tCommonFrigateBaseState::mOnHostChanged()
{}
void tCommonFrigateBaseState::mOnTimedInterval( int32 timerID )
{}
void tCommonFrigateBaseState::mOnStateChange( tActor* actor, tState* stateID, eStateEvent eventType )
{}
void tCommonFrigateBaseState::mOnCommStateChange( tActor* actor, int32 state, int32 buttonID, eStateEvent eventType )
{}


