/********************************************************************************************************\

	Mission:	Multiplayer Battlefest Lite
	Script:		"Mul_11Tinyfest"
	Descript:	Destroy your oppenent 3 times (each time your opponent comes at you with a different ship).

	Created by:		Unknown Scripter for SFC v1
	Last Updated:	Daniel J. Suleski	04/19/00
					Initial restructuring of files
					DJS					04/20/00
					Added the logic from the original battlefest idea.  However, rather than the player
					ships progressing from Frigate to Heavy Cruiser to Dreadnought, the player now starts
					with whatever ship he or she has chosen from the start, then is given a Heavy Cruiser,
					then a Dreadnought.
					DJS					04/24/00
					Teams no longer have 2 ships.  They will only start with the frigate, then the heavy
					cruiser, finally the dreadnought.
					DJS					04/25/00
					Victory condition has spawned off into a "world condition".  This new class is used
					to hold the state of "worldly" events.  In this case, every single ship that is
					destroyed, which determines the winner.
					DJS					06/04/00
					Including a common directory for all base classes.  This should save time when
					converting to the other battlefest scripts.
					DJS					06/09/00
					Victory condition changes, testing on both machines.  Got rid of all the team files
					totally and am now just using the common files.  Wow!
					DJS					06/11/00
					Random starting point ship generation.  tScript::mNewTeam() overload is now called
					correctly.  Testing on 2 machines.
					DJS					06/12/00
					A team is now set as being lost if the controlling player leaves the game harshly.
					DJS					07/26/00
					Second pass.
					DJS					08/23/00
					Map overrides.
					DJS					08/26/00
					Text check.  Disengage now destroys ships.
					DJS						09/26/00
					Meta script modifications

\********************************************************************************************************/
#include "MissionText.h"
#include "MissionMaps.h"
#include "Mul_11Tinyfest.h"
#include "CommonTeam.h"
#include "VictoryCondition.h"
#include "WorldConditions.h"

#include "teamtracker.h"
#include "scriptstructs.h"
DEFINE_SCRIPT_CLASS( tMul_11Tinyfest );

ShipList global_sl;
ShipList narrowed_sl;

int32 ShipListComplete = 0;

ShipList sl_array[6][kNumPlayableRaces][6];
ShipList sl_array_backup[6][kNumPlayableRaces][6];


tMul_11Tinyfest::tMul_11Tinyfest()
{}

//---------------------------------------------------------------------------------------------
// returns mission specs used by Dynaverse to build campaigns
void tMul_11Tinyfest::mScriptSpecs( tMissionSpec* Specs )
{
	Specs->fMissionTitle = Messages[kMissionTitle_msg];
	Specs->fMissionDescription = Messages[kDescription_msg];
	Specs->fHelpTags = Messages[kHelpTags_msg];
	Specs->fMissionType = kMultiplayerMission;
	Specs->fPlayerRace = kSpecAnyRace;
	Specs->fNumShips = kMissSpecNoShip;
	Specs->fMenuStates = kNoMenuButtons;
	Specs->fBandwidthPart = static_cast< eBandwidthPart >( k1Band | k5Client );
	Specs->fGenericFlags = kDisableCapture;

	const tTeamSpec& team1 = mCreateTeamSpec(	"Team 1",
												kTeam1,
												kMaxChance,
												kFalse,
												kPlayableTeam,
												kMinChance,
												kSpecAnyRace,
												kAnyRace,
												typeid( tCommonTeam ) );

	const tTeamSpec& team2 = mCreateTeamSpec(	"Team 2",
												kTeam2,
												kMaxChance,
												kFalse,
												kPlayableTeam,
												kMinChance,
												kSpecAnyRace,
												kAnyRace,
												typeid( tCommonTeam ) );

	const tTeamSpec& team3 = mCreateTeamSpec(	"Team 3",
												kTeam3,
												kMaxChance,
												kFalse,
												kPlayableTeam,
												kMinChance,
												kSpecAnyRace,
												kAnyRace,
												typeid( tCommonTeam ) );

	const tTeamSpec& team4 = mCreateTeamSpec(	"Team 4",
												kTeam4,
												kMaxChance,
												kFalse,
												kPlayableTeam,
												kMinChance,
												kSpecAnyRace,
												kAnyRace,
												typeid( tCommonTeam ) );

	const tTeamSpec& team5 = mCreateTeamSpec(	"Team 5",
												kTeam5,
												kMaxChance,
												kFalse,
												kPlayableTeam,
												kMinChance,
												kSpecAnyRace,
												kAnyRace,
												typeid( tCommonTeam ) );

	const tTeamSpec& team6 = mCreateTeamSpec(	"Team 6",
												kTeam6,
												kMaxChance,
												kFalse,
												kPlayableTeam,
												kMinChance,
												kSpecAnyRace,
												kAnyRace,
												typeid( tCommonTeam ) );

	Specs->mSetupTeam( team1 );
	Specs->mSetupTeam( team2 );
	Specs->mSetupTeam( team3 );
	Specs->mSetupTeam( team4 );
	Specs->mSetupTeam( team5 );
	Specs->mSetupTeam( team6 );
}

//---------------------------------------------------------------------------------------------
// called at the start of mission initialization - use to set prestige points 
// and override mission defaults such as:
//		allied race
//		enemy race
//		system name
// and also returns map index to use
int32 tMul_11Tinyfest::mInitializeStart( tDynaverseScriptInfo& info )
{
	// pick a map
	return 1;
}

//---------------------------------------------------------------------------------------------
// called to create ships before or during the mission
// Mode is user supplied value( expect for 0, which is initial setup call )
void tMul_11Tinyfest::mCreateExternalShips( int32 Mode )
{}

//---------------------------------------------------------------------------------------------
// called at the end of mission initialization - use to return briefing message
int32 tMul_11Tinyfest::mInitializeFinished( void )
{
	// return the index to the briefing message we want to use
	return( kBriefing_msg );
}

//---------------------------------------------------------------------------------------------
// called whenever a ship is created after a mission has already started
void tMul_11Tinyfest::mNewInternalShip( tShipInfo* Ship )
{}

void tMul_11Tinyfest::mStartMission()
{
	tScript::mStartMission();


	const int kRelationsCount = 6;
	int32 tagList[kRelationsCount] =
	{
		kTagA,
		kTagB,
		kTagC,
		kTagD,
		kTagE,
		kTagF,
	};

	std::string relationships[kRelationsCount][kRelationsCount] =
	{
		//		 A     B     C     D     E     F
		/*A   */ "AI", "WD", "WD", "WD", "WD", "WD",
		/*B   */ "WD", "AI", "WD", "WD", "WD", "WD",
		/*C   */ "WD", "WD", "AI", "WD", "WD", "WD",
		/*D   */ "WD", "WD", "WD", "AI", "WD", "WD",
		/*E   */ "WD", "WD", "WD", "WD", "AI", "WD",
		/*F   */ "WD", "WD", "WD", "WD", "WD", "AI",
	};

	fMissionInfo->mSetTagRelations( tagList, ( std::string* )relationships, kRelationsCount );

	//
	//	The last thing that should be done before the mission actually starts is to check if the game
	//	has already been won.  This can most likely happen as a result of all teams having the same
	//	team tag.  Therefore, everyone is allied.
	//
	gWC.mCheckForGameEnd();

}

void tMul_11Tinyfest::mNewTeam( const tTeamScriptDescription& teamScriptDescription )
{
	switch ( teamScriptDescription.fTeamTag )
	{
	case kTagA:
	case kTagB:
	case kTagC:
	case kTagD:
	case kTagE:
	case kTagF:
		{
			mMission()->mSetupTeam(	teamScriptDescription.fTeam,
									teamScriptDescription.fTeamTag,
									teamScriptDescription.fRace,
									teamScriptDescription.fHumanControlled,
									typeid( tCommonTeam ) );
		}
		break;
	}
}

/*

	HELPER NOTE:	Make certain to call tScript::mASCIIOverrides() first before assigning custom values.

*/
void tMul_11Tinyfest::mASCIIOverrides( tMapOverrides* Map )
{
	tScript::mASCIIOverrides( Map );

	Map->fTacticalMapIcon['G'] = kObjectPlayerShip;
	Map->fTacticalMapIcon['H'] = kObjectPlayerShip;
	Map->fTacticalMapIcon['I'] = kObjectPlayerShip;
	Map->fTacticalMapIcon['J'] = kObjectPlayerShip;
	Map->fTacticalMapIcon['K'] = kObjectPlayerShip;
	Map->fTacticalMapIcon['L'] = kObjectPlayerShip;
}
